summaryrefslogtreecommitdiffstats
path: root/tdecore/tdehw/tdenetworkconnections.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/tdehw/tdenetworkconnections.h')
-rw-r--r--tdecore/tdehw/tdenetworkconnections.h23
1 files changed, 14 insertions, 9 deletions
diff --git a/tdecore/tdehw/tdenetworkconnections.h b/tdecore/tdehw/tdenetworkconnections.h
index 7cc6bae6c..806c162a8 100644
--- a/tdecore/tdehw/tdenetworkconnections.h
+++ b/tdecore/tdehw/tdenetworkconnections.h
@@ -1003,7 +1003,7 @@ class TDENetworkEventQueueEvent_Private
TDENetworkConnectionStatus::TDENetworkConnectionStatus previousConnStatus;
TDEMACAddress BSSID;
TQString message;
- TQString hwAddress;
+ TQString deviceNode;
TDENetworkAPEventType::TDENetworkAPEventType apevent;
TDENetworkDeviceEventType::TDENetworkDeviceEventType ndevent;
TDENetworkVPNEventType::TDENetworkVPNEventType vpnevent;
@@ -1020,12 +1020,12 @@ class TDECORE_EXPORT TDENetworkConnectionManager : public TQObject
public:
/**
* Constructor.
* @param macAddress The MAC address of the hardware device
* If an empty MAC address is passed, this object will make global networking backend
* methods available exclusively (TDENetworkDeviceType::BackendOnly).
*/
- TDENetworkConnectionManager(TQString macAddress);
-
+ TDENetworkConnectionManager(TDENetworkDevice *networkDevice);
+
/**
* Destructor.
*/
@@ -1209,7 +1209,7 @@ class TDECORE_EXPORT TDENetworkConnectionManager : public TQObject
* If the global connection state has changed, @param hwAddress will be empty, otherwise it will contain the MAC address
* of the networking hardware that has changed state.
*/
- void networkDeviceStateChanged(TDENetworkConnectionStatus::TDENetworkConnectionStatus newState, TDENetworkConnectionStatus::TDENetworkConnectionStatus previousState, TQString hwAddress);
+ void networkDeviceStateChanged(TDENetworkConnectionStatus::TDENetworkConnectionStatus newState, TDENetworkConnectionStatus::TDENetworkConnectionStatus previousState, TQString deviceNode);
/**
* Emitted whenever the status of a wireless access point changes
@@ -1254,6 +1254,11 @@ class TDECORE_EXPORT TDENetworkConnectionManager : public TQObject
virtual TDENetworkConnectionList* connections();
/**
+ * @return the interface name of this device
+ */
+ TQString deviceNode();
+
+ /**
* @return the MAC address of this device
*/
TQString deviceMACAddress();
@@ -1318,7 +1323,7 @@ class TDECORE_EXPORT TDENetworkConnectionManager : public TQObject
* @internal This method must be called by the network backend whenever a device changes state
* It emits the appropriate signals to notify client applications of the state change
*/
- void internalNetworkDeviceStateChanged(TDENetworkConnectionStatus::TDENetworkConnectionStatus newState, TQString hwAddress=TQString::null);
+ void internalNetworkDeviceStateChanged(TDENetworkConnectionStatus::TDENetworkConnectionStatus newState, TQString deviceNode=TQString::null);
/**
* @internal This method must be called by the network backend whenever a wireless access point changes state
@@ -1350,7 +1355,7 @@ class TDECORE_EXPORT TDENetworkConnectionManager : public TQObject
protected:
TDENetworkConnectionList* m_connectionList;
TDENetworkHWNeighborList* m_hwNeighborList;
- TQString m_macAddress;
+ TDENetworkDevice* m_networkDevice;
TDENetworkGlobalManagerFlags::TDENetworkGlobalManagerFlags m_prevConnectionStatus;
TQMap<TQString, TDENetworkConnectionStatus::TDENetworkConnectionStatus> m_prevDeviceStatus;
TQTimer* m_emissionTimer;
@@ -1528,7 +1533,7 @@ class TDECORE_EXPORT TDEGlobalNetworkManager : public TQObject
* If the global connection state has changed, @param hwAddress will be empty, otherwise it will contain the MAC address
* of the networking hardware that has changed state.
*/
- void networkDeviceStateChanged(TDENetworkConnectionStatus::TDENetworkConnectionStatus newState, TDENetworkConnectionStatus::TDENetworkConnectionStatus previousState, TQString hwAddress);
+ void networkDeviceStateChanged(TDENetworkConnectionStatus::TDENetworkConnectionStatus newState, TDENetworkConnectionStatus::TDENetworkConnectionStatus previousState, TQString deviceNode);
/**
* Emitted whenever the status of a wireless access point changes
@@ -1020,12 +1020,12 @@ class TDECORE_EXPORT TDENetworkConnectionManager : public TQObject
/**
* Constructor.
- * @param macAddress The MAC address of the hardware device
- * If an empty MAC address is passed, this object will make global networking backend
+ * @param networkDevice Pointer to holder network device
+ * If the network device is passed null, this object will make global networking backend
* methods available exclusively (TDENetworkDeviceType::BackendOnly).
*/